@@ -1,14 +1,16 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-convertible-1.1.0.0/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: convertible
-version: 1.0.11.1
-id: convertible-1.0.11.1-3f3e3789aca848a4dd9113e591940c67
+version: 1.1.0.0
+id: convertible-1.1.0.0-887b62ebc9ebf9c4752b8921d6a67093
 
 license: BSD3
 copyright: Copyright (c) 2009-2011 John Goerzen
-maintainer: John Goerzen <jgoerzen@complete.org>
+maintainer: Nicolas Wu <nicolas.wu@gmail.com>
 stability: Stable
 homepage: http://hackage.haskell.org/cgi-bin/hackage-scripts/package/convertible
 package-url:
+synopsis: Typeclasses and instances for converting between types
 description: convertible provides a typeclass with a single function
              that is designed to help convert between different types: numeric
              values, dates and times, and the like.  The conversions perform bounds
@@ -30,7 +32,7 @@ description: convertible provides a typeclass with a single function
              Convertible is backed by an extensive test suite and passes tests
              on GHC and Hugs.
 category: Data
-author: John Goerzen
+author: John Goerzen, Nicolas Wu
 pkgpath: devel/hs-convertible
 exposed: True
 exposed-modules: Data.Convertible Data.Convertible.Base
@@ -39,26 +41,27 @@ exposed-modules: Data.Convertible Data.Convertible.Base
                  Data.Convertible.Instances.Num Data.Convertible.Instances.Text
                  Data.Convertible.Instances.Time
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/convertible-1.0.11.1
-library-dirs: /usr/local/lib/ghc/convertible-1.0.11.1
-hs-libraries: HSconvertible-1.0.11.1
+trusted: False
+import-dirs: /usr/local/lib/ghc/convertible-1.1.0.0
+library-dirs: /usr/local/lib/ghc/convertible-1.1.0.0
+hs-libraries: HSconvertible-1.1.0.0
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
-         bytestring-0.9.1.10-4e62762ee9b2a5d0cc5bc2fbaaeefd53
-         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
-         mtl-2.0.1.0-3e464329054b7660133198d73c31aca5
-         old-locale-1.0.0.2-25ff1e5e0486bb3cf2cb85cb7daf8f22
-         old-time-1.0.0.6-249d424df19da9487f0cb7da3ccb0868
-         text-0.11.1.5-a9f0a532672121c1439a824b6891e297
-         time-1.2.0.3-ad46a3ade48e0011608895f44cc02a52
+depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         bytestring-0.10.4.0-84f2b632cefc94e5dfeafb660607fcbd
+         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
+         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
+         old-locale-1.0.0.6-50b0125c49f76af85dc7aa22975cdc34
+         old-time-1.1.0.2-e3f776e97c1a6ff1770b04943a7ef7c6
+         text-1.1.0.0-72236c81391c0a9a303f37559690d8fe
+         time-1.4.2-311aa8e77a6af87dc3d662d572df62ec
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-convertible-1.0.11.1/html/convertible.haddock
-haddock-html: /usr/local/share/doc/hs-convertible-1.0.11.1/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-convertible-1.1.0.0/html/convertible.haddock
+haddock-html: /usr/local/share/doc/hs-convertible-1.1.0.0/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
